==> haskell-fsnotify0.3-0.3.0.1-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-ErzRk3eAnJ12BVVpSPd6cH
key:                  fsnotify-0.3.0.1-ErzRk3eAnJ12BVVpSPd6cH
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  badb7e86cd8af9c6a397223b6a01437b
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-ErzRk3eAnJ12BVVpSPd6cH
depends:
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-G00YK5DT6TmcX4N0cnVTQ
    shelly-1.10.0.1-LujBbSdwcst48p2bZcJj3y text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.3-DV17HkZ4p37LF0rLylNPml

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify0.3-0.3.0.1-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-Is7bbNG3DyzDWmjcs6hNFI
key:                  fsnotify-0.3.0.1-Is7bbNG3DyzDWmjcs6hNFI
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  b9188435549a50eba2bef2c7f78b6e34
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-Is7bbNG3DyzDWmjcs6hNFI
depends:
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-G00YK5DT6TmcX4N0cnVTQ
    shelly-1.10.0.1-BqF4NEvgK7d6tsJJs18xfA text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.3-B5vTjW95eDK44yEFtO1GZ

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
